@@ -59,7 +59,6 @@
 #include "game.h"
 #include "stats-dialog.h"
 #include "util.h"
-#include "ar-fullscreen-button.h"
 
 #include "window.h"
 
@@ -87,20 +86,6 @@
 #define C_(context, string) (_(string))
 #endif
 
-/* On maemo5, the toolbar doesn't have enough space to show a
- * significant amount of text, so we always use the banner here.
- */
-#if defined(HAVE_HILDON) && (defined(HAVE_MAEMO_3) || defined(HAVE_MAEMO_4))
-#define MAEMO_TOOLBAR_BANNER
-#endif
-
-/* On maemo5, there's no hardware key to exit the fullscreen mode. So we show
- * an overlay button to restore normal mode, if the toolbar is hidden too.
- */
-#if defined(HAVE_HILDON) && defined(HAVE_MAEMO_5)
-#define LEAVE_FULLSCREEN_BUTTON
-#endif
-
 /* define this to enable a debug menu */
 /* #undef ENABLE_DEBUG_UI */
 
@@ -117,7 +102,7 @@ enum
 #ifdef HAVE_HILDON
   ACTION_ACCEL_UNDO_MOVE,
 #endif
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
+#ifndef HAVE_MAEMO
   ACTION_LEAVE_FULLSCREEN,
 #endif
   LAST_ACTION
@@ -132,17 +117,15 @@ struct _AisleriotWindowPrivate
   GamesCardTheme *theme;
 
 #ifdef HAVE_HILDON
-  guint game_message_hash;
-#ifdef MAEMO_TOOLBAR_BANNER
   GtkLabel *game_message_label;
-#endif /* MAEMO_TOOLBAR_BANNER */
+  guint game_message_hash;
 #else
   GtkStatusbar *statusbar;
   guint game_message_id;
   GtkWidget *score_box;
   GtkWidget *score_label;
   GtkWidget *clock;
-#endif /* HAVE_HILDON */
+#endif
 
   GtkUIManager *ui_manager;
   GtkActionGroup *action_group;
@@ -169,10 +152,6 @@ struct _AisleriotWindowPrivate
   GtkWidget *hint_dialog;
 #endif
 
-#ifdef LEAVE_FULLSCREEN_BUTTON
-  GtkWidget *fullscreen_button;
-#endif
-
   guint load_idle_id;
 
   guint use_pixbuf_drawing : 1;
@@ -180,7 +159,6 @@ struct _AisleriotWindowPrivate
   guint freecell_mode : 1;
   guint toolbar_visible : 1;
   guint statusbar_visible : 1;
-  guint fullscreen : 1;
 };
 
 enum {
@@ -195,30 +173,12 @@ enum {
   COL_GAME_FILE
 };
 
-#define SELECTED_PATH_DATA_KEY "selected-path"
-
 static void
 select_game_row_activated_cb (GtkWidget *widget,
                               GtkTreePath *path,
                               GtkTreeViewColumn *column,
                               GtkDialog *dialog)
 {
-  g_assert (path != NULL);
-
-#ifdef HAVE_MAEMO_5
-  /* On maemo5 with a treeview in a pannable area, the selection
-   * handling is special. There _never_ is any row selected!
-   * Instead, we get a row-activated signal (which normally is only
-   * emitted when double-clicking a row) when the user selects a row.
-   *
-   * Since we can't use the selection, we need to store the activated
-   * row somewhere else.
-   */
-  g_object_set_data_full (G_OBJECT (dialog), SELECTED_PATH_DATA_KEY,
-                          gtk_tree_path_copy (path),
-                          (GDestroyNotify) gtk_tree_path_free);
-#endif /* HAVE_MAEMO_5 */
-
   /* Handle a double click by faking a click on the OK button. */
   gtk_dialog_response (dialog, GTK_RESPONSE_OK);
 }
@@ -232,21 +192,9 @@ select_game_response_cb (GtkWidget *dialog,
   GtkTreeModel *model;
   GtkTreeIter iter;
   char *game_file = NULL;
-#ifdef HAVE_MAEMO_5
-  GtkTreePath *path;
-#endif
 
-  if (response != GTK_RESPONSE_OK)
-    goto done;
-
-#ifdef HAVE_MAEMO_5
-  /* See the comment in select_game_row_activated_cb() above. */
-  if ((path = g_object_get_data (G_OBJECT (dialog), SELECTED_PATH_DATA_KEY)) != NULL &&
-      gtk_tree_model_get_iter (GTK_TREE_MODEL (priv->game_choice_store), &iter, path)) {
-    model = GTK_TREE_MODEL (priv->game_choice_store);
-#else
-  if (gtk_tree_selection_get_selected (priv->game_choice_selection, &model, &iter)) {
-#endif
+  if (response == GTK_RESPONSE_OK &&
+      gtk_tree_selection_get_selected (priv->game_choice_selection, &model, &iter)) {
     gtk_tree_model_get (model, &iter,
                         COL_GAME_FILE, &game_file,
                         -1);
@@ -259,7 +207,6 @@ select_game_response_cb (GtkWidget *dialog,
     g_free (game_file);
   }
 
-done:
   gtk_widget_destroy (dialog);
 }
 
@@ -275,8 +222,8 @@ select_game_cb (GtkAction *action,
   GtkWidget *scrolled_window;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
-  GtkWidget *hbox;
-  GtkTreeIter current_iter;
+  GtkWidget *hbox, *content_area;
+  GtkTreeIter current_iter, selection_iter;
   gboolean current_iter_set = FALSE;
   const char *current_game_file;
   const char *games_dir;
@@ -351,12 +298,12 @@ select_game_cb (GtkAction *action,
 
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  gtk_box_set_spacing (GTK_BOX (content_area), 2);
 
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-                      hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
   g_signal_connect (list_view, "row-activated",
                     G_CALLBACK (select_game_row_activated_cb), dialog);
 
@@ -408,12 +355,13 @@ select_game_cb (GtkAction *action,
    * and scroll to it.
    */
   if (current_iter_set) {
+    gtk_tree_selection_select_iter (selection, &current_iter);
+  }
+
+  if (gtk_tree_selection_get_selected (selection, NULL, &selection_iter)) {
     GtkTreePath *path;
 
-    gtk_tree_selection_select_iter (selection, &current_iter);
-
-    /* Scroll view to the current item */
-    path = gtk_tree_model_get_path (GTK_TREE_MODEL (list), &current_iter);
+    path = gtk_tree_model_get_path (GTK_TREE_MODEL (list), &selection_iter);
     gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (list_view), path, NULL,
                                   TRUE,
 				  0.5, 0.0);
@@ -1061,31 +1009,6 @@ debug_pixbuf_drawing_cb (GtkToggleAction *action,
 
 #endif /* ENABLE_DEBUG_UI */
 
-static void
-set_fullscreen_button_active (AisleriotWindow *window)
-{
-#ifdef LEAVE_FULLSCREEN_BUTTON
-  AisleriotWindowPrivate *priv = window->priv;
-  gboolean active;
-
-  active = priv->fullscreen && !priv->toolbar_visible;
-  if (!active) {
-    if (priv->fullscreen_button != NULL) {
-      ar_fullscreen_button_set_active (AR_FULLSCREEN_BUTTON (priv->fullscreen_button), FALSE);
-    }
-
-    return;
-  }
-
-  if (active && priv->fullscreen_button == NULL) {
-    priv->fullscreen_button = ar_fullscreen_button_new (GTK_WINDOW (window),
-                                                        GTK_CORNER_TOP_RIGHT);
-  }
-
-  ar_fullscreen_button_set_active (AR_FULLSCREEN_BUTTON (priv->fullscreen_button), TRUE);
-#endif /* LEAVE_FULLSCREEN_BUTTON */
-}
-
 static void
 toolbar_toggled_cb (GtkToggleAction *action,
                     AisleriotWindow *window)
@@ -1100,8 +1023,6 @@ toolbar_toggled_cb (GtkToggleAction *action,
   priv->toolbar_visible = state != FALSE;
 
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), state);
-
-  set_fullscreen_button_active (window);
 }
 
 #ifndef HAVE_HILDON
@@ -1133,19 +1054,15 @@ set_fullscreen_actions (AisleriotWindow *window,
 {
   AisleriotWindowPrivate *priv = window->priv;
 
-  priv->fullscreen = is_fullscreen;
-
 #ifndef HAVE_MAEMO
   g_object_set (priv->main_menu, "visible", !is_fullscreen, NULL);
-#endif /* HAVE_MAEMO */
 
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
   gtk_action_set_visible (priv->action[ACTION_LEAVE_FULLSCREEN], is_fullscreen);
   g_object_set (gtk_ui_manager_get_widget (priv->ui_manager, "/Toolbar/LeaveFullscreenSep"),
                 "visible", is_fullscreen,
                 "draw", FALSE,
                 NULL);
-#endif /* !HAVE_MAEMO || !MAEMO_TOOLBAR_BANNER */
+#endif
 
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (priv->action[ACTION_FULLSCREEN]),
                                 is_fullscreen);
@@ -1167,7 +1084,7 @@ fullscreen_toggled_cb (GtkToggleAction *action,
   }
 }
 
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
+#ifndef HAVE_MAEMO
 
 static void
 leave_fullscreen_cb (GtkAction *action,
@@ -1176,7 +1093,7 @@ leave_fullscreen_cb (GtkAction *action,
   gtk_window_unfullscreen (window);
 }
 
-#endif /* !HAVE_MAEMO || !MAEMO_TOOLBAR_BANNER */
+#endif /* !HAVE_MAEMO */
 
 static void
 clickmove_toggle_cb (GtkToggleAction *action,
@@ -1943,9 +1860,7 @@ game_type_changed_cb (AisleriotGame *game,
   gtk_action_set_visible (priv->action[ACTION_DEAL], dealable);
 
 #ifdef HAVE_HILDON
-#ifdef MAEMO_TOOLBAR_BANNER
   gtk_label_set_text (priv->game_message_label, NULL);
-#endif /* MAEMO_TOOLBAR_BANNER */
 #else
   games_clock_reset (GAMES_CLOCK (priv->clock));
 
@@ -1953,7 +1868,7 @@ game_type_changed_cb (AisleriotGame *game,
 
   show_scores = (features & FEATURE_SCORE_HIDDEN) == 0;
   g_object_set (priv->score_box, "visible", show_scores, NULL);
-#endif /* HAVE_HILDON */
+#endif
 
   priv->changing_game_type = FALSE;
 }
@@ -1962,21 +1877,17 @@ static void
 game_new_cb (AisleriotGame *game,
              AisleriotWindow *window)
 {
-#if defined(MAEMO_TOOLBAR_BANNER) || !defined(HAVE_HILDON)
   AisleriotWindowPrivate *priv = window->priv;
-#endif
 
   update_statistics_display (window);
 
 #ifdef HAVE_HILDON
-#ifdef MAEMO_TOOLBAR_BANNER
   gtk_label_set_text (priv->game_message_label, NULL);
-#endif /* MAEMO_TOOLBAR_BANNER */
 #else
   games_clock_reset (GAMES_CLOCK (priv->clock));
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
-#endif /* HAVE_HILDON */
+#endif
 }
 
 static void
@@ -1986,17 +1897,12 @@ game_statusbar_message_cb (AisleriotGame *game,
 {
   AisleriotWindowPrivate *priv = window->priv;
 #ifdef HAVE_HILDON
-#ifdef MAEMO_TOOLBAR_BANNER
   gtk_label_set_text (priv->game_message_label, message);
-#endif
 
   /* The banners are annoying, but until I get a better idea, use them
    * when the toolbar is hidden.
    */
-#ifdef MAEMO_TOOLBAR_BANNER
-  if (!priv->toolbar_visible)
-#endif
-  {
+  if (!priv->toolbar_visible) {
     guint hash;
 
     if (message != NULL && message[0] != '\0') {
@@ -2241,8 +2147,6 @@ aisleriot_window_state_event (GtkWidget *widget,
 
     set_fullscreen_actions (window, is_fullscreen);
 
-    set_fullscreen_button_active (window);
-
 #ifndef HAVE_HILDON
 #if GTK_CHECK_VERSION (2, 11, 0)
     gtk_statusbar_set_has_resize_grip (priv->statusbar, !is_maximised && !is_fullscreen);
@@ -2344,13 +2248,13 @@ aisleriot_window_init (AisleriotWindow *window)
 #endif /* ENABLE_CARD_THEMES_INSTALLER */
 
     /* Toolbar-only actions */
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
+#ifndef HAVE_MAEMO
     { "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL,
       G_CALLBACK (leave_fullscreen_cb) },
-#endif /* !HAVE_MAEMO || !MAEMO_TOOLBAR_BANNER */
 #ifndef HAVE_HILDON
     { "ThemeMenu", NULL, N_("_Card Style"), NULL, NULL, NULL },
 #endif /* !HAVE_HILDON */
+#endif /* !HAVE_MAEMO */
 
 #ifdef ENABLE_DEBUG_UI
     /* Debug UI actions */
@@ -2435,9 +2339,9 @@ aisleriot_window_init (AisleriotWindow *window)
 #ifdef HAVE_HILDON
     "AccelUndoMove",
 #endif /* HAVE_HILDON */
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
+#ifndef HAVE_MAEMO
     "LeaveFullscreen",
-#endif /* !HAVE_MAEMO || !MAEMO_TOOLBAR_BANNER */
+#endif /* !HAVE_MAEMO */
   };
 
   static const char ui_description[] =
@@ -2557,10 +2461,10 @@ aisleriot_window_init (AisleriotWindow *window)
         "<toolitem action='RedoMove'/>"
         "<toolitem action='Deal'/>"
         "<toolitem action='Hint'/>"
-#if !defined(HAVE_MAEMO) || !defined(MAEMO_TOOLBAR_BANNER)
+#ifndef HAVE_MAEMO
         "<separator name='LeaveFullscreenSep' expand='true'/>"
         "<toolitem action='LeaveFullscreen'/>"
-#endif /* !HAVE_MAEMO || !MAEMO_TOOLBAR_BANNER */
+#endif
 #ifdef ENABLE_DEBUG_UI
         "<toolitem action='DebugGameFirst'/>"
         "<toolitem action='DebugGamePrev'/>"
@@ -2583,18 +2487,20 @@ aisleriot_window_init (AisleriotWindow *window)
   char *theme_name;
   GamesCardTheme *theme;
   guint i;
-#ifndef HAVE_HILDON
+#ifdef HAVE_HILDON
+  GtkToolItem *tool_item;
+#else
   const char *env;
   GtkStatusbar *statusbar;
-  GtkWidget *statusbar_hbox,*label, *time_box;
+  GtkWidget *statusbar_hbox, *statusbar_label, *label, *time_box;
+  GtkContainer *statusbar_frame;
+  GList *list;
 #endif
 
   g_assert (G_N_ELEMENTS (names) == LAST_ACTION);
 
   priv = window->priv = AISLERIOT_WINDOW_GET_PRIVATE (window);
 
-  priv->fullscreen = FALSE;
-
   priv->game = aisleriot_game_new ();
 
 #ifdef HAVE_HILDON
@@ -2676,11 +2582,15 @@ aisleriot_window_init (AisleriotWindow *window)
    * which we put in the statusbar's frame instead.
    */
   statusbar_hbox = gtk_hbox_new (FALSE, 24);
-  g_object_ref (statusbar->label);
-  gtk_container_remove (GTK_CONTAINER (statusbar->frame), statusbar->label);
-  gtk_box_pack_start (GTK_BOX (statusbar_hbox), statusbar->label, TRUE, TRUE, 0);
-  g_object_unref (statusbar->label);
-  gtk_container_add (GTK_CONTAINER (statusbar->frame), statusbar_hbox);
+  list = gtk_container_get_children (GTK_CONTAINER (statusbar));
+  statusbar_frame = GTK_CONTAINER (list->data);
+  g_list_free (list);
+  statusbar_label = gtk_bin_get_child (GTK_BIN (statusbar_frame));
+  g_object_ref (statusbar_label);
+  gtk_container_remove (statusbar_frame, statusbar_label);
+  gtk_box_pack_start (GTK_BOX (statusbar_hbox), statusbar_label, TRUE, TRUE, 0);
+  g_object_unref (statusbar_label);
+  gtk_container_add (statusbar_frame, statusbar_hbox);
   gtk_widget_show (statusbar_hbox);
 
   /* Score */
@@ -2717,10 +2627,7 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->main_menu = gtk_ui_manager_get_widget (priv->ui_manager, MAIN_MENU_UI_PATH);
   priv->toolbar = gtk_ui_manager_get_widget (priv->ui_manager, TOOLBAR_UI_PATH);
 
-#ifdef MAEMO_TOOLBAR_BANNER
-{
-  GtkToolItem *tool_item;
-
+#ifdef HAVE_HILDON
   /* It's a bit ugly to mess with the toolbar like this,
    * but it's simpler than to implement a dedicated action
    * which creates a tool item which ellipsises its label...
@@ -2735,8 +2642,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
   gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), tool_item, -1);
   gtk_widget_show_all (GTK_WIDGET (tool_item));
-}
-#endif /* MAEMO_TOOLBAR_BANNER */
+#endif
 
   /* Defer building the card themes menu until its parent's menu is opened */
 #ifdef HAVE_HILDON
@@ -2902,11 +2808,11 @@ aisleriot_window_init (AisleriotWindow *window)
 }
 
 static void
-aisleriot_window_dispose (GObject *object)
+aisleriot_window_finalize (GObject *object)
 {
   AisleriotWindow *window = AISLERIOT_WINDOW (object);
   AisleriotWindowPrivate *priv = window->priv;
-  
+
 #ifdef HAVE_CLUTTER
   g_signal_handlers_disconnect_by_func (gtk_widget_get_settings (GTK_WIDGET (window)),
                                         G_CALLBACK (settings_changed_cb),
@@ -2931,27 +2837,6 @@ aisleriot_window_dispose (GObject *object)
     gtk_widget_destroy (GTK_WIDGET (priv->stats_dialog));
     g_assert (priv->stats_dialog == NULL);
   }
-  
-#ifdef LEAVE_FULLSCREEN_BUTTON
-  if (priv->fullscreen_button != NULL) {
-    gtk_widget_destroy (GTK_WIDGET (priv->fullscreen_button));
-    priv->fullscreen_button = NULL;
-  }
-#endif
-
-  if (priv->load_idle_id != 0) {
-    g_source_remove (priv->load_idle_id);
-    priv->load_idle_id = 0;
-  }
-
-  G_OBJECT_CLASS (aisleriot_window_parent_class)->dispose (object);
-}
-
-static void
-aisleriot_window_finalize (GObject *object)
-{
-  AisleriotWindow *window = AISLERIOT_WINDOW (object);
-  AisleriotWindowPrivate *priv = window->priv;
 
   if (priv->theme) {
     g_object_unref (priv->theme);
@@ -2964,6 +2849,10 @@ aisleriot_window_finalize (GObject *object)
                                         0, 0, NULL, NULL, window);
   g_object_unref (priv->game);
 
+  if (priv->load_idle_id != 0) {
+    g_source_remove (priv->load_idle_id);
+  }
+
   G_OBJECT_CLASS (aisleriot_window_parent_class)->finalize (object);
 }
 
@@ -2973,7 +2862,6 @@ aisleriot_window_class_init (AisleriotWindowClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  gobject_class->dispose = aisleriot_window_dispose;
   gobject_class->finalize = aisleriot_window_finalize;
 
   widget_class->window_state_event = aisleriot_window_state_event;
