@@ -51,9 +51,9 @@ prompt for usage and a list of options.
 """
 
 
-__revision__ = '$Rev: 8277 $'
-__date__ = '$Date: 2008-11-07 20:48:10 -0600 (Fri, 07 Nov 2008) $'
-__author__ = '$Author: rancell $'
+__revision__ = '$Rev$'
+__date__ = '$Date$'
+__author__ = '$Author$'
 
 
 import sys
@@ -700,7 +700,7 @@ class Reader:
             try:
                 tag, data = self.read_chunk()
             except ValueError, e:
-                raise Error('Chunk error: ' + e.message)
+                raise Error('Chunk error: ' + str(e))
 
             # print >> sys.stderr, tag, len(data)
             if tag == 'IHDR': # http://www.w3.org/TR/PNG/#11IHDR
