@@ -1,20 +1,20 @@
 /* 
-   Copyright © 2004 Callum McKenzie
-   Copyright © 2007, 2008 Christian Persch
+  Copyright © 2004 Callum McKenzie
+  Copyright © 2007, 2008 Christian Persch
 
-   This library is free software; you can redistribute it and'or modify
-   it under the terms of the GNU Library General Public License as published 
-   by the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This library is free software: you can redistribute it and/or modify
+  it under the terms of the GNU Lesser General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+  You should have received a copy of the GNU Lesser General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 /* Authors:   Callum McKenzie <callum@physics.otago.ac.nz> */
 
@@ -256,9 +256,13 @@ games_card_images_set_property (GObject *object,
   GamesCardImages *images = GAMES_CARD_IMAGES (object);
 
   switch (prop_id) {
-  case PROP_THEME:
-    games_card_images_set_theme (images, g_value_get_object (value));
-    break;
+    case PROP_THEME:
+      games_card_images_set_theme (images, g_value_get_object (value));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -271,9 +275,13 @@ games_card_images_get_property (GObject *object,
   GamesCardImages *images = GAMES_CARD_IMAGES (object);
 
   switch (prop_id) {
-  case PROP_THEME:
-    g_value_set_object (value, games_card_images_get_theme (images));
-    break;
+    case PROP_THEME:
+      g_value_set_object (value, games_card_images_get_theme (images));
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -375,7 +383,7 @@ games_card_images_set_cache_mode (GamesCardImages * images,
                                   GamesCardImagesCacheMode mode)
 {
   g_return_if_fail (GAMES_IS_CARD_IMAGES (images));
-  g_return_if_fail (mode >= 0 && mode < LAST_CACHE_MODE);
+  g_return_if_fail (mode < LAST_CACHE_MODE);
 
   if (mode == images->cache_mode)
     return;
@@ -445,10 +453,11 @@ games_card_images_set_size (GamesCardImages * images,
  *
  * Returns: the currently selected card size
  */
-CardSize
-games_card_images_get_size (GamesCardImages * images)
+void
+games_card_images_get_size (GamesCardImages *images,
+                            CardSize *size)
 {
-  return games_card_theme_get_size (images->theme);
+  games_card_theme_get_size (images->theme, size);
 }
 
 /**
@@ -520,8 +529,7 @@ games_card_images_get_card_pixbuf_by_id (GamesCardImages * images,
   guint idx;
 
   g_return_val_if_fail (GAMES_IS_CARD_IMAGES (images), NULL);
-  g_return_val_if_fail ((card_id >= 0)
-                        && (card_id < GAMES_CARDS_TOTAL), NULL);
+  g_return_val_if_fail ((card_id < GAMES_CARDS_TOTAL), NULL);
   g_return_val_if_fail (images->cache_mode == CACHE_PIXBUFS, NULL);
 
   LOG_CALL (images);
@@ -589,10 +597,8 @@ GdkPixbuf *
 games_card_images_get_card_pixbuf (GamesCardImages * images,
                                    Card card, gboolean highlighted)
 {
-  guint index = _games_card_to_index (card);
-
   return games_card_images_get_card_pixbuf_by_id (images,
-                                                  index,
+                                                  _games_card_to_index (card),
                                                   highlighted);
 }
 
@@ -621,8 +627,7 @@ games_card_images_get_card_pixmap_by_id (GamesCardImages * images,
   guint idx;
 
   g_return_val_if_fail (GAMES_IS_CARD_IMAGES (images), NULL);
-  g_return_val_if_fail ((card_id >= 0)
-                        && (card_id < GAMES_CARDS_TOTAL), NULL);
+  g_return_val_if_fail ((card_id < GAMES_CARDS_TOTAL), NULL);
   g_return_val_if_fail (images->cache_mode == CACHE_PIXMAPS, NULL);
   g_return_val_if_fail (images->drawable != NULL, NULL);
 
@@ -741,10 +746,8 @@ GdkPixmap *
 games_card_images_get_card_pixmap (GamesCardImages * images,
                                    Card card, gboolean highlighted)
 {
-  guint index = _games_card_to_index (card);
-
   return games_card_images_get_card_pixmap_by_id (images,
-                                                  index,
+                                                  _games_card_to_index (card),
                                                   highlighted);
 }
 
@@ -895,7 +898,7 @@ GdkPixmap *
 games_card_images_get_card_pixmap_by_suit_and_rank (GamesCardImages * images,
                                                     guint suit, guint rank)
 {
-  g_return_val_if_fail (((suit >= GAMES_CARDS_CLUBS) &&
+  g_return_val_if_fail (( /* (suit >= GAMES_CARDS_CLUBS) && */
                          (suit <= GAMES_CARDS_SPADES)), NULL);
   g_return_val_if_fail (((rank >= GAMES_CARD_ACE) &&
                          (rank <= GAMES_CARD_ACE_HIGH)), NULL);
