@@ -1,3 +1,4 @@
+#include <config.h>
 #include <stdlib.h>
 #include <check.h>
 
@@ -43,28 +44,6 @@ START_TEST (test_games_clock_new)
 END_TEST
 
 
-/* TESTCASE 2: Setting and getting time with games-clock.c */
-START_TEST (test_games_clock_set)
-{
-  GtkWidget *clock;
-  time_t end;
-
-  clock = games_clock_new ();
-  fail_if (!GTK_IS_WIDGET (clock), 
-           "games_clock_new() failed.");
-
-  games_clock_set_seconds (GAMES_CLOCK (clock), 10);
-  games_clock_add_seconds (GAMES_CLOCK (clock), 10);
-  end = games_clock_get_seconds (GAMES_CLOCK (clock));
-
-  fail_unless (end == 20, 
-               "Expected current time to be 20, "
-	       "but the games-clock returned %d instead", end);
-  
-}
-END_TEST
-
-
 /* Create test suite for libgames-support  */
 static Suite *
 libgames_support_suite (void)
@@ -75,13 +54,6 @@ libgames_support_suite (void)
   tcase_add_test (tc1, test_games_clock_new);
   tcase_add_checked_fixture (tc1, fx_setup_gtk, fx_teardown_gtk);
   suite_add_tcase (s, tc1);
-
-  TCase *tc2 = tcase_create ("games-clock-set");
-  tcase_add_test (tc2, test_games_clock_set);
-  tcase_add_checked_fixture (tc2, fx_setup_gtk, fx_teardown_gtk);
-  tcase_set_timeout(tc2, 0);
-  suite_add_tcase (s, tc2);
-
   
   return s;
 }
